Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(278)

Unified Diff: pkg/code_transformers/lib/src/test_harness.dart

Issue 367023003: Roll forward revision 37912. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Code review changes. Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/barback/pubspec.yaml ('k') | pkg/code_transformers/pubspec.yaml » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/code_transformers/lib/src/test_harness.dart
diff --git a/pkg/code_transformers/lib/src/test_harness.dart b/pkg/code_transformers/lib/src/test_harness.dart
index e579a5879078d990a32a0e51111184cae3a98793..334020470523cbaec4e7c587317f0cb7c07d9336 100644
--- a/pkg/code_transformers/lib/src/test_harness.dart
+++ b/pkg/code_transformers/lib/src/test_harness.dart
@@ -64,8 +64,8 @@ class TestHelper implements PackageProvider {
});
logSubscription = barback.log.listen((entry) {
- // Ignore info messages.
- if (entry.level == LogLevel.INFO) return;
+ // Ignore info and fine messages.
+ if (entry.level == LogLevel.INFO || entry.level == LogLevel.FINE) return;
if (entry.level == LogLevel.ERROR) errorSeen = true;
// We only check messages when an expectation is provided.
if (messages == null) return;
« no previous file with comments | « pkg/barback/pubspec.yaml ('k') | pkg/code_transformers/pubspec.yaml » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698